from argparse import ArgumentParser
from argparse import Namespace
from kubernetes import client, config
import re

def get_args() -> Namespace:
    parser = ArgumentParser(
        prog="Cluster Search Thing",
        description="General utility for finding resources for game server bot"
    )
    games = {"health", "reflex", "minecraft"}
    parser.add_argument('-g', '--game', required=False, choices=games)

    admin = {"health"}
    parser.add_argument('-a', '--admin', required=False, choices=admin)
    return parser.parse_args()

def k8s_api(config_path: str) -> client.api.core_v1_api.CoreV1Api:
    config.load_kube_config("../config.yaml")
    return client.CoreV1Api()

def get_admin_service_details(args: ArgumentParser, api: client.api.core_v1_api.CoreV1Api):
    print('admin thing requested', args.admin)
    services = api.list_service_for_all_namespaces(label_selector=f'app={args.admin}')
    if len(services.items) == 0:
        print(f'Unable to find {args.admin} amongst the admin-services')
        return
    
    port = services.items[0].spec.ports[0].port
    node_ips = list(filter(lambda a: a.type == 'ExternalIP', api.list_node().items[0].status.addresses))
    ipv4 = list(filter(lambda item: not re.match('[\d\.]{3}\d', item.address), node_ips))[0].address
    ipv6 = list(filter(lambda item: re.match('[\d\.]{3}\d', item.address), node_ips))[0].address
    
    print(f'{args.admin} --> {ipv4}:{port} ~~> {ipv6}:{port}')

def get_game_server_ip(args: ArgumentParser, api: client.api.core_v1_api.CoreV1Api):
    services = api.list_service_for_all_namespaces(label_selector=f'app={args.game}')
    port = services.items[0].spec.ports[0].port

    # Collecting the IPV4 of the node that contains the pod(container)
    # we actually care about. Since these pods only have 1 container
    # Now we collect specific data about the game server we requested
    node_ips  = list(filter(lambda a: a.type == 'ExternalIP', api.list_node().items[0].status.addresses))
    ipv4 = list(filter(lambda item: not re.match('[\d\.]{3}\d', item.address), node_ips))[0].address
    ipv6 = list(filter(lambda item: re.match('[\d\.]{3}\d', item.address), node_ips))[0].address
    
    print(f'{args.game} --> {ipv4}:{port} ~~> {ipv6}:{port}')


if __name__ == '__main__':
    args = get_args()
    api = k8s_api('../config.yaml')

    if args.game:
        get_game_server_ip(args, api)
    
    if args.admin:
        get_admin_service_details(args, api)
    
